@@ -120,7 +120,7 @@ personal_nlu = {
     '[do you, know], [have you, heard],'
     '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
     '}, {virtual reality, vr, v r,oculus,vive,rift,morpheus}]'
-    '#CNC(virtual_reality)':
+    '#CNC(virtual_reality) #CNC(vr_experience)':
         'SYSTEM:virtual_reality_intro',
 
     # transition to corona
