@@ -517,7 +517,6 @@ class TokLimit(Macro):
                 return False
 
 
-
 class Transition(Macro):
     """
 
@@ -977,7 +976,27 @@ macros_common_dict = {
     'ISP': IsPlural(),
 }
 
+class ExtractList(Macro):
+    """
+    Extracts all matching phrases from user utterance, given ontology categories or phrase literals, and
+    stores them in the provided variable name as a list
 
+    args:
+        [0] - variable name
+        [1 - n] - ontology categories and phrase literals
+    """
+
+    def __init__(self, kb):
+        self.onte = ONTE(kb)
+
+    def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
+        var = args[0]
+        if var not in vars:
+            vars[var] = set()
+        # find matches
+        matches = self.onte(ngrams, None, args[1:])
+        matches.update({arg for arg in args[1:] if arg in ngrams})
+        vars[var].update(matches)
 
 
 
